pub mod services;

lazy_static! {
    pub static ref ROUTE: String = "/api/v1".to_string();
}
